# Get-SecurityPackage

## SYNOPSIS
Enumerates all loaded security packages (SSPs).

Author: Matthew Graeber (@mattifestation)  
License: BSD 3-Clause  
Required Dependencies: None  
Optional Dependencies: None

## SYNTAX

```
Get-SecurityPackage
```

## DESCRIPTION
Get-SecurityPackage is a wrapper for secur32!EnumerateSecurityPackages.
It also parses the returned SecPkgInfo struct array.

## EXAMPLES

### -------------------------- EXAMPLE 1 --------------------------
```
Get-SecurityPackage
```

## PARAMETERS

## INPUTS

## OUTPUTS

## NOTES

## RELATED LINKS

